<!---
(C) Copyright 2019 Hewlett Packard Enterprise Development LP

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.
--->

# Thanks To...

* HPE - I work for them, and this wouldn't have been possible without them!
* The HPE Open Source Review Board, especially Schreck (Jim Schreckengast), Clém (Clément Poulain), and Paul Holland.
* Gunaseelan Lakshminarayanan, my manager at HPE
* Tom Phelan, who sponsored the HPE OSRB review
* @guillaumeeb for giving great feedback on the code
* @minrk for giving a ton of help on how to integrate with JupyterHub
* @mwilbz for making a great issue and patch
* @itsnagaraj for making a great issue, providing a lot of thought and code, and being very patient with development of the project
* @killerwhile for jumping in and making some really neat additions
* @duongnt for being very patient and checking the spelling in the code and in the docs
* @jpobley for being willing to speak up about the software being broken
* @0nebody for writing the role/group code
